@@ -132,6 +132,7 @@ fn bin_main() -> BinResult<()> {
                             .long("no-sort")
                             .num_args(0)
                             .action(ArgAction::SetTrue)
+                            .hide_short_help(true)
                             .help("Use files exactly in the order given, rather than sorted"))
                         .arg(Arg::new("quiet")
                             .long("quiet")
@@ -144,7 +145,6 @@ fn bin_main() -> BinResult<()> {
                             .num_args(1..)
                             .value_parser(NonEmptyStringValueParser::new())
                             .use_value_delimiter(false)
-                            .trailing_var_arg(true)
                             .required(true))
                         .arg(Arg::new("repeat")
                             .long("repeat")
@@ -155,6 +155,7 @@ fn bin_main() -> BinResult<()> {
                         .arg(Arg::new("fixed-color")
                             .long("fixed-color")
                             .help("Always include this color in the palette")
+                            .hide_short_help(true)
                             .num_args(1)
                             .action(ArgAction::Append)
                             .value_parser(parse_colors)
